"""
## Heading 1

This will also recognise markdown.

```sh
!/bin/bash

echo "markdown syntax highlighting."
```

## Heading 2

...

Lorem ipsum.


## Heading 3

...

## Mermaid Support

```mermaid
graph TD;
    A-->B;
    A-->C;
    B-->D;
    C-->D;
```
"""
