"""
<!-- IMPORTANT: ReST is supported and gets rendered by `pdoc`: -->
.. warning::
    This is a DEMO project, in a "real" project you'd put things that are more meaningful and specific here.

    This would include stuff like a summary of your *API*, key concepts etc.

.. include:: ../../README.md

"""
